@@ -19,6 +19,7 @@ CONTENT_TYPES = (
     'application/vnd.openxmlformats-officedocument.wordprocessingml.footer+xml',
 )
 
+
 class MailMerge(object):
     def __init__(self, file):
         self.zip = ZipFile(file)
@@ -75,8 +76,9 @@ class MailMerge(object):
             parent.remove(child)
 
     def write(self, file):
+        # Replace all remaining merge fields with empty values
         for field in self.get_merge_fields():
-            self.merge(**{field:''})
+            self.merge(**{field: ''})
 
         output = ZipFile(file, 'w', ZIP_DEFLATED)
         for zi in self.zip.filelist:
@@ -114,10 +116,10 @@ class MailMerge(object):
     def merge_rows(self, anchor, rows):
         table, idx, template = self.__find_row_anchor(anchor)
         del table[idx]
-        for row_data in rows:
+        for i, row_data in enumerate(rows):
             row = deepcopy(template)
             self.merge([row], **row_data)
-            table.append(row)
+            table.insert(idx + i, row)
 
     def __find_row_anchor(self, field, parts=None):
         if not parts:
